@@ -1,9 +1,9 @@
-/* $Id: mipmap.c,v 1.5 1997/07/24 01:28:44 brianp Exp $ */
+/* $Id: mipmap.c,v 1.3.2.1 1999/12/12 17:23:33 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.4
- * Copyright (C) 1995-1997  Brian Paul
+ * Version:  3.1
+ * Copyright (C) 1995-1999  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -23,6 +23,42 @@
 
 /*
  * $Log: mipmap.c,v $
+ * Revision 1.3.2.1  1999/12/12 17:23:33  brianp
+ * removed unneeded code in gluBuild1DMipmaps()
+ *
+ * Revision 1.3  1999/11/09 06:16:59  brianp
+ * replace GLint with GLsizei in a gluScaleImage, gluBuild1/2DMipmaps()
+ *
+ * Revision 1.2  1999/09/14 00:30:28  brianp
+ * fixed pixel packing/unpacking code in gluBuild2DMipmaps()
+ *
+ * Revision 1.1.1.1  1999/08/19 00:55:42  jtg
+ * Imported sources
+ *
+ * Revision 1.13  1999/03/05 17:49:06  brianp
+ * added support for GL_EXT_abgr (devernay@istar.fr)
+ *
+ * Revision 1.12  1999/01/03 03:23:15  brianp
+ * now using GLAPIENTRY and GLCALLBACK keywords (Ted Jump)
+ *
+ * Revision 1.11  1998/09/18 02:44:03  brianp
+ * further changes to gluScaleImage() per Randy Frank
+ *
+ * Revision 1.10  1998/09/17 03:20:26  brianp
+ * fixed another bug in gluScaleImage() per Sven Panne
+ *
+ * Revision 1.9  1998/07/31 03:06:20  brianp
+ * tweaked the gluScaleImage() function per Randy Frank
+ *
+ * Revision 1.8  1998/07/08 01:02:53  brianp
+ * if gluBuildxDMipmaps() width or height <= 0 return GLU_INVALID_VALUE
+ *
+ * Revision 1.7  1998/07/01 00:18:02  brianp
+ * if gluBuildxDMipmaps() width or height <= 0 just return 0
+ *
+ * Revision 1.6  1998/06/01 01:06:41  brianp
+ * small update for Next/OpenStep from Alexander Mai
+ *
  * Revision 1.5  1997/07/24 01:28:44  brianp
  * changed precompiled header symbol from PCH to PC_HEADER
  *
@@ -66,7 +102,7 @@
 
 
 /* To work around optimizer bug in MSVC4.1 */
-#ifdef __WIN32__
+#if defined(__WIN32__) && !defined(OPENSTEP)
 void dummy(GLuint j, GLuint k){
 }
 #else
@@ -74,10 +110,10 @@ void dummy(GLuint j, GLuint k){
 #endif
 
 
-GLint APIENTRY gluScaleImage( GLenum format,
-                              GLint widthin, GLint heightin,
+GLint GLAPIENTRY gluScaleImage( GLenum format,
+                              GLsizei widthin, GLsizei heightin,
                               GLenum typein, const void *datain,
-                              GLint widthout, GLint heightout,
+                              GLsizei widthout, GLsizei heightout,
                               GLenum typeout, void *dataout )
 {
    GLint components, i, j, k;
@@ -108,6 +144,9 @@ GLint APIENTRY gluScaleImage( GLenum format,
 	 components = 3;
 	 break;
       case GL_RGBA:
+#ifdef GL_EXT_abgr
+      case GL_ABGR_EXT:
+#endif
 	 components = 4;
 	 break;
       default:
@@ -287,8 +326,14 @@ GLint APIENTRY gluScaleImage( GLenum format,
     * Scale the image!
     */
 
-   sx = (GLfloat) widthin / (GLfloat) widthout;
-   sy = (GLfloat) heightin / (GLfloat) heightout;
+   if (widthout > 1)
+      sx = (GLfloat) (widthin-1) / (GLfloat) (widthout-1);
+   else
+      sx = (GLfloat) (widthin-1);
+   if (heightout > 1)
+      sy = (GLfloat) (heightin-1) / (GLfloat) (heightout-1);
+   else
+      sy = (GLfloat) (heightin-1);
 
 /*#define POINT_SAMPLE*/
 #ifdef POINT_SAMPLE
@@ -316,11 +361,15 @@ GLint APIENTRY gluScaleImage( GLenum format,
 
       for (i=0;i<heightout;i++) {
 	 i0 = i * sy;
-	 i1 = (i+1) * sy - EPSILON;
+	 i1 = i0 + 1;
+	 if (i1 >= heightin) i1 = heightin-1;
+/*	 i1 = (i+1) * sy - EPSILON;*/
 	 alpha = i*sy - i0;
 	 for (j=0;j<widthout;j++) {
 	    j0 = j * sx;
-	    j1 = (j+1) * sx - EPSILON;
+	    j1 = j0 + 1;
+	    if (j1 >= widthin) j1 = widthin-1;
+/*	    j1 = (j+1) * sx - EPSILON; */
 	    beta = j*sx - j0;
 
 	    /* compute weighted average of pixels in rect (i0,j0)-(i1,j1) */
@@ -348,10 +397,14 @@ GLint APIENTRY gluScaleImage( GLenum format,
 
       for (i=0;i<heightout;i++) {
 	 i0 = i * sy;
-	 i1 = (i+1) * sy - EPSILON;
+	 i1 = i0 + 1;
+	 if (i1 >= heightin) i1 = heightin-1; 
+/*	 i1 = (i+1) * sy - EPSILON; */
 	 for (j=0;j<widthout;j++) {
 	    j0 = j * sx;
-	    j1 = (j+1) * sx - EPSILON;
+	    j1 = j0 + 1;
+	    if (j1 >= widthin) j1 = widthin-1;
+/*	    j1 = (j+1) * sx - EPSILON; */
 
 	    dst = tempout + (i * widthout + j) * components;
 
@@ -556,6 +609,9 @@ static GLint bytes_per_pixel( GLenum format, GLenum type )
 	 n = 3;
 	 break;
       case GL_RGBA:
+#ifdef GL_EXT_abgr
+      case GL_ABGR_EXT:
+#endif
 	 n = 4;
 	 break;
       default:
@@ -582,8 +638,8 @@ static GLint bytes_per_pixel( GLenum format, GLenum type )
 /*
  * WARNING: This function isn't finished and has never been tested!!!!
  */
-GLint APIENTRY gluBuild1DMipmaps( GLenum target, GLint components,
-                                  GLint width, GLenum format,
+GLint GLAPIENTRY gluBuild1DMipmaps( GLenum target, GLint components,
+                                  GLsizei width, GLenum format,
                                   GLenum type, const void *data )
 {
    GLubyte *texture;
@@ -591,6 +647,9 @@ GLint APIENTRY gluBuild1DMipmaps( GLenum target, GLint components,
    GLint new_width, max_width;
    GLint i, j, k, l;
 
+   if (width < 1)
+      return GLU_INVALID_VALUE;
+
    glGetIntegerv( GL_MAX_TEXTURE_SIZE, &max_width );
    max_levels = ilog2( max_width ) + 1;
 
@@ -646,25 +705,26 @@ GLint APIENTRY gluBuild1DMipmaps( GLenum target, GLint components,
 
    free( texture );
 
-   /* make sure remaining mipmap levels are removed */
-   for (l=levels;l<max_levels;l++) {
-      glTexImage1D( GL_TEXTURE_1D, l, components, 0, 0,
-		    format, GL_UNSIGNED_BYTE, NULL );
-   }
-
    return 0;
 }
 
 
 
-GLint APIENTRY gluBuild2DMipmaps( GLenum target, GLint components,
-                                  GLint width, GLint height, GLenum format,
+GLint GLAPIENTRY gluBuild2DMipmaps( GLenum target, GLint components,
+                                  GLsizei width, GLsizei height, GLenum format,
                                   GLenum type, const void *data )
 {
    GLint w, h, maxsize;
    void *image, *newimage;
    GLint neww, newh, level, bpp;
    int error;
+   GLboolean done;
+   GLint retval = 0;
+   GLint unpackrowlength, unpackalignment, unpackskiprows, unpackskippixels;
+   GLint packrowlength, packalignment, packskiprows, packskippixels;
+
+   if (width < 1 || height < 1)
+      return GLU_INVALID_VALUE;
 
    glGetIntegerv( GL_MAX_TEXTURE_SIZE, &maxsize );
 
@@ -683,6 +743,24 @@ GLint APIENTRY gluBuild2DMipmaps( GLenum target, GLint components,
       return GLU_INVALID_ENUM;
    }
 
+   /* Get current glPixelStore values */
+   glGetIntegerv( GL_UNPACK_ROW_LENGTH, &unpackrowlength );
+   glGetIntegerv( GL_UNPACK_ALIGNMENT, &unpackalignment );
+   glGetIntegerv( GL_UNPACK_SKIP_ROWS, &unpackskiprows );
+   glGetIntegerv( GL_UNPACK_SKIP_PIXELS, &unpackskippixels );
+   glGetIntegerv( GL_PACK_ROW_LENGTH, &packrowlength );
+   glGetIntegerv( GL_PACK_ALIGNMENT, &packalignment );
+   glGetIntegerv( GL_PACK_SKIP_ROWS, &packskiprows );
+   glGetIntegerv( GL_PACK_SKIP_PIXELS, &packskippixels );
+
+   /* set pixel packing */
+   glPixelStorei( GL_PACK_ROW_LENGTH, 0 );
+   glPixelStorei( GL_PACK_ALIGNMENT, 1 );
+   glPixelStorei( GL_PACK_SKIP_ROWS, 0 );
+   glPixelStorei( GL_PACK_SKIP_PIXELS, 0 );
+
+   done = GL_FALSE;
+
    if (w!=width || h!=height) {
       /* must rescale image to get "top" mipmap texture image */
       image = malloc( (w+4) * h * bpp );
@@ -692,7 +770,8 @@ GLint APIENTRY gluBuild2DMipmaps( GLenum target, GLint components,
       error = gluScaleImage( format, width, height, type, data,
 			     w, h, type, image );
       if (error) {
-	 return error;
+         retval = error;
+         done = GL_TRUE;
       }
    }
    else {
@@ -700,7 +779,15 @@ GLint APIENTRY gluBuild2DMipmaps( GLenum target, GLint components,
    }
 
    level = 0;
-   while (1) {
+   while (!done) {
+      if (image != data) {
+         /* set pixel unpacking */
+         glPixelStorei( GL_UNPACK_ROW_LENGTH, 0 );
+         glPixelStorei( GL_UNPACK_ALIGNMENT, 1 );
+         glPixelStorei( GL_UNPACK_SKIP_ROWS, 0 );
+         glPixelStorei( GL_UNPACK_SKIP_PIXELS, 0 );
+      }
+
       glTexImage2D( target, level, components, w, h, 0, format, type, image );
 
       if (w==1 && h==1)  break;
@@ -715,7 +802,8 @@ GLint APIENTRY gluBuild2DMipmaps( GLenum target, GLint components,
       error =  gluScaleImage( format, w, h, type, image,
 			      neww, newh, type, newimage );
       if (error) {
-	 return error;
+         retval = error;
+         done = GL_TRUE;
       }
 
       if (image!=data) {
@@ -732,6 +820,16 @@ GLint APIENTRY gluBuild2DMipmaps( GLenum target, GLint components,
       free( image );
    }
 
-   return 0;
+   /* Restore original glPixelStore state */
+   glPixelStorei( GL_UNPACK_ROW_LENGTH, unpackrowlength );
+   glPixelStorei( GL_UNPACK_ALIGNMENT, unpackalignment );
+   glPixelStorei( GL_UNPACK_SKIP_ROWS, unpackskiprows );
+   glPixelStorei( GL_UNPACK_SKIP_PIXELS, unpackskippixels );
+   glPixelStorei( GL_PACK_ROW_LENGTH, packrowlength );
+   glPixelStorei( GL_PACK_ALIGNMENT, packalignment );
+   glPixelStorei( GL_PACK_SKIP_ROWS, packskiprows );
+   glPixelStorei( GL_PACK_SKIP_PIXELS, packskippixels );
+
+   return retval;
 }
 
