@@ -1,9 +1,9 @@
-/* $Id: nurbs.c,v 1.11 1998/02/07 14:29:11 brianp Exp $ */
+/* $Id: nurbs.c,v 1.1.1.1 1999/08/19 00:55:42 jtg Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.6
- * Copyright (C) 1995-1997  Brian Paul
+ * Version:  3.1
+ * Copyright (C) 1995-1999  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -23,6 +23,18 @@
 
 /*
  * $Log: nurbs.c,v $
+ * Revision 1.1.1.1  1999/08/19 00:55:42  jtg
+ * Imported sources
+ *
+ * Revision 1.14  1999/01/03 03:23:15  brianp
+ * now using GLAPIENTRY and GLCALLBACK keywords (Ted Jump)
+ *
+ * Revision 1.13  1998/06/01 01:07:49  brianp
+ * small update for Next/OpenStep from Alexander Mai
+ *
+ * Revision 1.12  1998/03/15 18:14:30  brianp
+ * fixed a compiler cast warning
+ *
  * Revision 1.11  1998/02/07 14:29:11  brianp
  * fixed casting problem in gluNurbsCallback, again
  *
@@ -82,13 +94,13 @@ call_user_error( GLUnurbsObj *nobj, GLenum error )
         (*(nobj->error_callback))(error);
     }
     else {
-       printf("NURBS error %d %s\n", error, gluErrorString(error) );
+       printf("NURBS error %d %s\n", error, (char *) gluErrorString(error) );
     }
 }
 
 
 
-GLUnurbsObj * APIENTRY gluNewNurbsRenderer( void )
+GLUnurbsObj * GLAPIENTRY gluNewNurbsRenderer( void )
 {
    GLUnurbsObj *n;
    GLfloat tmp_viewport[4];
@@ -132,7 +144,7 @@ GLUnurbsObj * APIENTRY gluNewNurbsRenderer( void )
 
 
 
-void APIENTRY gluDeleteNurbsRenderer( GLUnurbsObj *nobj )
+void GLAPIENTRY gluDeleteNurbsRenderer( GLUnurbsObj *nobj )
 {
    if (nobj) {
       free( nobj );
@@ -141,7 +153,7 @@ void APIENTRY gluDeleteNurbsRenderer( GLUnurbsObj *nobj )
 
 
 
-void APIENTRY gluLoadSamplingMatrices( GLUnurbsObj *nobj,
+void GLAPIENTRY gluLoadSamplingMatrices( GLUnurbsObj *nobj,
                   const GLfloat modelMatrix[16],
                   const GLfloat projMatrix[16],
                   const GLint viewport[4] )
@@ -158,7 +170,7 @@ void APIENTRY gluLoadSamplingMatrices( GLUnurbsObj *nobj,
 }
 
 
-void APIENTRY gluNurbsProperty( GLUnurbsObj *nobj, GLenum property, GLfloat value )
+void GLAPIENTRY gluNurbsProperty( GLUnurbsObj *nobj, GLenum property, GLfloat value )
 {
    GLenum val;
 
@@ -244,7 +256,7 @@ if(val==GLU_OUTLINE_PATCH)
 }
 
 
-void APIENTRY gluGetNurbsProperty( GLUnurbsObj *nobj, GLenum property, GLfloat *value )
+void GLAPIENTRY gluGetNurbsProperty( GLUnurbsObj *nobj, GLenum property, GLfloat *value )
 {
    switch (property) {
       case GLU_SAMPLING_TOLERANCE:
@@ -266,7 +278,7 @@ void APIENTRY gluGetNurbsProperty( GLUnurbsObj *nobj, GLenum property, GLfloat *
 
 
 
-void APIENTRY gluBeginCurve( GLUnurbsObj *nobj )
+void GLAPIENTRY gluBeginCurve( GLUnurbsObj *nobj )
 {
     if(nobj->nurbs_type==GLU_NURBS_CURVE)
     {
@@ -281,7 +293,7 @@ void APIENTRY gluBeginCurve( GLUnurbsObj *nobj )
 }
 
 
-void APIENTRY gluEndCurve( GLUnurbsObj * nobj )
+void GLAPIENTRY gluEndCurve( GLUnurbsObj * nobj )
 {
     if(nobj->nurbs_type==GLU_NURBS_NONE)
     {
@@ -319,7 +331,7 @@ void APIENTRY gluEndCurve( GLUnurbsObj * nobj )
 }
 
 
-void APIENTRY gluNurbsCurve( GLUnurbsObj *nobj, GLint nknots, GLfloat *knot,
+void GLAPIENTRY gluNurbsCurve( GLUnurbsObj *nobj, GLint nknots, GLfloat *knot,
             GLint stride, GLfloat *ctlarray, GLint order, GLenum type )
 {
     if(nobj->nurbs_type==GLU_NURBS_TRIM)
@@ -428,7 +440,7 @@ void APIENTRY gluNurbsCurve( GLUnurbsObj *nobj, GLint nknots, GLfloat *knot,
 }
 
 
-void APIENTRY gluBeginSurface( GLUnurbsObj *nobj )
+void GLAPIENTRY gluBeginSurface( GLUnurbsObj *nobj )
 {
     switch(nobj->nurbs_type)
     {
@@ -454,7 +466,7 @@ void APIENTRY gluBeginSurface( GLUnurbsObj *nobj )
 }
 
 
-void APIENTRY gluEndSurface( GLUnurbsObj * nobj )
+void GLAPIENTRY gluEndSurface( GLUnurbsObj * nobj )
 {
     switch(nobj->nurbs_type)
     {
@@ -502,7 +514,7 @@ void APIENTRY gluEndSurface( GLUnurbsObj * nobj )
 }
 
 
-void APIENTRY gluNurbsSurface( GLUnurbsObj *nobj,
+void GLAPIENTRY gluNurbsSurface( GLUnurbsObj *nobj,
               GLint sknot_count, GLfloat *sknot,
               GLint tknot_count, GLfloat *tknot,
               GLint s_stride, GLint t_stride,
@@ -587,20 +599,20 @@ void APIENTRY gluNurbsSurface( GLUnurbsObj *nobj,
 }
 
 
-void APIENTRY
-gluNurbsCallback( GLUnurbsObj *nobj, GLenum which, void (CALLBACK *fn)())
+void GLAPIENTRY
+gluNurbsCallback( GLUnurbsObj *nobj, GLenum which, void (GLCALLBACK *fn)())
 {
-#ifdef __CYGWIN32__
+#if defined(__CYGWIN32__) || defined(OPENSTEP)
     nobj->error_callback = (void(*)(GLenum))fn;
 #else
-    nobj->error_callback = (void(CALLBACK*)(GLenum))fn;
+    nobj->error_callback = (void(GLCALLBACK*)(GLenum))fn;
 #endif
 
     if(which!=GLU_ERROR)
         call_user_error(nobj,GLU_INVALID_ENUM);
 }
 
-void APIENTRY
+void GLAPIENTRY
 gluBeginTrim( GLUnurbsObj *nobj )
 {
 #if 0
@@ -636,7 +648,7 @@ fprintf(stderr,"NURBS - trimming not supported yet\n");
 #endif
 }
 
-void APIENTRY
+void GLAPIENTRY
 gluPwlCurve( GLUnurbsObj *nobj, GLint count, GLfloat *array, GLint stride,
     GLenum type)
 {
@@ -690,7 +702,7 @@ gluPwlCurve( GLUnurbsObj *nobj, GLint count, GLfloat *array, GLint stride,
 #endif
 }
 
-void APIENTRY
+void GLAPIENTRY
 gluEndTrim( GLUnurbsObj *nobj )
 {
     if(nobj->nurbs_type!=GLU_NURBS_TRIM)
