@@ -1,9 +1,9 @@
-/* $Id: quadric.c,v 1.16 1998/06/01 01:08:36 brianp Exp $ */
+/* $Id: quadric.c,v 1.1.1.1.2.1 1999/12/15 12:59:29 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.6
- * Copyright (C) 1995-1997  Brian Paul
+ * Version:  3.1
+ * Copyright (C) 1995-1999  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -23,6 +23,21 @@
 
 /*
  * $Log: quadric.c,v $
+ * Revision 1.1.1.1.2.1  1999/12/15 12:59:29  brianp
+ * replaced 0 with 0.0 in sin, cos calls
+ *
+ * Revision 1.1.1.1  1999/08/19 00:55:42  jtg
+ * Imported sources
+ *
+ * Revision 1.19  1999/02/27 13:55:31  brianp
+ * fixed BeOS-related GLU typedef problems
+ *
+ * Revision 1.18  1999/01/03 03:23:15  brianp
+ * now using GLAPIENTRY and GLCALLBACK keywords (Ted Jump)
+ *
+ * Revision 1.17  1999/01/03 03:19:15  brianp
+ * rewrote some of gluCylinder
+ *
  * Revision 1.16  1998/06/01 01:08:36  brianp
  * small update for Next/OpenStep from Alexander Mai
  *
@@ -118,12 +133,12 @@
 
 
 
-struct GLUquadricObj {
+struct GLUquadric {
 	GLenum	DrawStyle;		/* GLU_FILL, LINE, SILHOUETTE, or POINT */
 	GLenum Orientation;		/* GLU_INSIDE or GLU_OUTSIDE */
 	GLboolean TextureFlag;		/* Generate texture coords? */
 	GLenum Normals;		/* GLU_NONE, GLU_FLAT, or GLU_SMOOTH */
-	void (CALLBACK *ErrorFunc)(GLenum err);	/* Error handler callback function */
+	void (GLCALLBACK *ErrorFunc)(GLenum err);	/* Error handler callback function */
 };
 
 
@@ -146,11 +161,11 @@ static void quadric_error( GLUquadricObj *qobj, GLenum error, const char *msg )
 
 
 
-GLUquadricObj * APIENTRY gluNewQuadric( void )
+GLUquadricObj * GLAPIENTRY gluNewQuadric( void )
 {
    GLUquadricObj *q;
 
-   q = (GLUquadricObj *) malloc( sizeof(struct GLUquadricObj) );
+   q = (GLUquadricObj *) malloc( sizeof(struct GLUquadric) );
    if (q) {
       q->DrawStyle = GLU_FILL;
       q->Orientation = GLU_OUTSIDE;
@@ -163,7 +178,7 @@ GLUquadricObj * APIENTRY gluNewQuadric( void )
 
 
 
-void APIENTRY gluDeleteQuadric( GLUquadricObj *state )
+void GLAPIENTRY gluDeleteQuadric( GLUquadricObj *state )
 {
    if (state) {
       free( (void *) state );
@@ -176,7 +191,7 @@ void APIENTRY gluDeleteQuadric( GLUquadricObj *state )
  * Set the drawing style to be GLU_FILL, GLU_LINE, GLU_SILHOUETTE,
  * or GLU_POINT.
  */
-void APIENTRY gluQuadricDrawStyle( GLUquadricObj *quadObject, GLenum drawStyle )
+void GLAPIENTRY gluQuadricDrawStyle( GLUquadricObj *quadObject, GLenum drawStyle )
 {
    if (quadObject && (drawStyle==GLU_FILL || drawStyle==GLU_LINE
 		   || drawStyle==GLU_SILHOUETTE || drawStyle==GLU_POINT)) {
@@ -192,7 +207,7 @@ void APIENTRY gluQuadricDrawStyle( GLUquadricObj *quadObject, GLenum drawStyle )
 /*
  * Set the orientation to GLU_INSIDE or GLU_OUTSIDE.
  */
-void APIENTRY gluQuadricOrientation( GLUquadricObj *quadObject,
+void GLAPIENTRY gluQuadricOrientation( GLUquadricObj *quadObject,
                                      GLenum orientation )
 {
    if (quadObject && (orientation==GLU_INSIDE || orientation==GLU_OUTSIDE)) {
@@ -208,8 +223,8 @@ void APIENTRY gluQuadricOrientation( GLUquadricObj *quadObject,
 /*
  * Set the error handler callback function.
  */
-void APIENTRY gluQuadricCallback( GLUquadricObj *qobj,
-                                  GLenum which, void (CALLBACK *fn)() )
+void GLAPIENTRY gluQuadricCallback( GLUquadricObj *qobj,
+                                  GLenum which, void (GLCALLBACK *fn)() )
 {
    /*
     * UGH, this is a mess!  I thought ANSI was a standard.
@@ -220,17 +235,19 @@ void APIENTRY gluQuadricCallback( GLUquadricObj *qobj,
 #elif defined(OPENSTEP)
       qobj->ErrorFunc = (void(*)(GLenum))fn;
 #elif defined(_WIN32)
-      qobj->ErrorFunc = (void(CALLBACK*)(int))fn;
+      qobj->ErrorFunc = (void(GLCALLBACK*)(int))fn;
 #elif defined(__STORM__)
-      qobj->ErrorFunc = (void(CALLBACK*)(GLenum))fn;
+      qobj->ErrorFunc = (void(GLCALLBACK*)(GLenum))fn;
+#elif defined(__BEOS__)
+      qobj->ErrorFunc = (void(*)(GLenum))fn;
 #else
-      qobj->ErrorFunc = (void(CALLBACK*)())fn;
+      qobj->ErrorFunc = (void(GLCALLBACK*)())fn;
 #endif
    }
 }
 
 
-void APIENTRY gluQuadricNormals( GLUquadricObj *quadObject, GLenum normals )
+void GLAPIENTRY gluQuadricNormals( GLUquadricObj *quadObject, GLenum normals )
 {
    if (quadObject
          && (normals==GLU_NONE || normals==GLU_FLAT || normals==GLU_SMOOTH)) {
@@ -239,7 +256,7 @@ void APIENTRY gluQuadricNormals( GLUquadricObj *quadObject, GLenum normals )
 }
 
 
-void APIENTRY gluQuadricTexture( GLUquadricObj *quadObject,
+void GLAPIENTRY gluQuadricTexture( GLUquadricObj *quadObject,
                                  GLboolean textureCoords )
 {
    if (quadObject) {
@@ -268,7 +285,7 @@ static void normal3f( GLfloat x, GLfloat y, GLfloat z )
 
 
 
-void APIENTRY gluCylinder( GLUquadricObj *qobj,
+void GLAPIENTRY gluCylinder( GLUquadricObj *qobj,
                            GLdouble baseRadius, GLdouble topRadius,
                            GLdouble height, GLint slices, GLint stacks )
 {
@@ -356,43 +373,47 @@ void APIENTRY gluCylinder( GLUquadricObj *qobj,
       glEnd();
    }
    else if (qobj->DrawStyle==GLU_FILL) {
-      GLfloat du = 1.0 / slices;
-      GLfloat dv = 1.0 / stacks;
-      GLfloat tcx = 0.0, tcy = 0.0;
-
-      for (i=0;i<slices;i++) {
-	 GLfloat x1 = -sin(i*da);
-	 GLfloat y1 = cos(i*da);
-	 GLfloat x2 = -sin((i+1)*da);
-	 GLfloat y2 = cos((i+1)*da);
-	 z = 0.0;
-	 r = baseRadius;
-	 tcy = 0.0;
-	 glBegin( GL_QUAD_STRIP );
-	 for (j=0;j<=stacks;j++) {
-	    if (nsign==1.0) {
-	       normal3f( x1*nsign, y1*nsign, nz*nsign );
-	       TXTR_COORD(tcx, tcy);
-	       glVertex3f( x1*r, y1*r, z );
-	       normal3f( x2*nsign, y2*nsign, nz*nsign );
-	       TXTR_COORD(tcx+du, tcy);
-	       glVertex3f( x2*r, y2*r, z );
-	    }
-	    else {
-	       normal3f( x2*nsign, y2*nsign, nz*nsign );
-	       TXTR_COORD(tcx, tcy);
-	       glVertex3f( x2*r, y2*r, z );
-	       normal3f( x1*nsign, y1*nsign, nz*nsign );
-	       TXTR_COORD(tcx+du, tcy);
-	       glVertex3f( x1*r, y1*r, z );
-	    }
-	    z += dz;
-	    r += dr;
-	    tcy += dv;
-	 }
-	 glEnd();
-	 tcx += du;
-      }
+      GLfloat ds = 1.0 / slices;
+      GLfloat dt = 1.0 / stacks;
+      GLfloat t = 0.0;
+      z = 0.0;
+      r = baseRadius;
+      for (j=0;j<stacks;j++) {
+         GLfloat s = 0.0;
+         glBegin( GL_QUAD_STRIP );
+         for (i=0;i<=slices;i++) {
+            GLfloat x, y;
+            if (i == slices) {
+               x = sin(0.0);
+               y = cos(0.0);
+            }
+            else {
+               x = sin(i * da);
+               y = cos(i * da);
+            }
+            if (nsign==1.0) {
+               normal3f( x*nsign, y*nsign, nz*nsign );
+               TXTR_COORD(s, t);
+               glVertex3f( x * r, y * r, z );
+               normal3f( x*nsign, y*nsign, nz*nsign );
+               TXTR_COORD(s, t + dt);
+               glVertex3f( x * (r + dr), y * (r + dr), z + dz);
+            }
+            else {
+               normal3f( x*nsign, y*nsign, nz*nsign );
+               TXTR_COORD(s, t);
+               glVertex3f( x * r, y * r, z );
+               normal3f( x*nsign, y*nsign, nz*nsign );
+               TXTR_COORD(s, t + dt);
+               glVertex3f( x * (r + dr), y * (r + dr), z + dz);
+            }
+            s += ds;
+         } /* for slices */
+         glEnd();
+         r += dr;
+         t += dt;
+         z += dz;
+      } /* for stacks */
    }
 }
 
@@ -400,7 +421,7 @@ void APIENTRY gluCylinder( GLUquadricObj *qobj,
 
 
 
-void APIENTRY gluSphere( GLUquadricObj *qobj,
+void GLAPIENTRY gluSphere( GLUquadricObj *qobj,
                          GLdouble radius, GLint slices, GLint stacks )
 {
    GLfloat rho, drho, theta, dtheta;
@@ -564,7 +585,7 @@ void APIENTRY gluSphere( GLUquadricObj *qobj,
 
 
 
-void APIENTRY gluDisk( GLUquadricObj *qobj,
+void GLAPIENTRY gluDisk( GLUquadricObj *qobj,
                        GLdouble innerRadius, GLdouble outerRadius,
                        GLint slices, GLint loops )
 {
@@ -712,7 +733,7 @@ void APIENTRY gluDisk( GLUquadricObj *qobj,
 
 
 
-void APIENTRY gluPartialDisk( GLUquadricObj *qobj, GLdouble innerRadius,
+void GLAPIENTRY gluPartialDisk( GLUquadricObj *qobj, GLdouble innerRadius,
                               GLdouble outerRadius, GLint slices, GLint loops,
                               GLdouble startAngle, GLdouble sweepAngle )
 {
